@@ -1,4 +1,4 @@
-from generic_camunda_client import Configuration
+from generic_camunda_client import Configuration, ApiClient
 
 
 class CamundaResources:
@@ -9,6 +9,8 @@ class CamundaResources:
 
     _client_configuration: Configuration = None
 
+    _api_client: ApiClient = None
+
     def __new__(cls):
         if cls._instance is None:
             print('Creating the object')
@@ -35,3 +37,20 @@ class CamundaResources:
     @client_configuration.setter
     def client_configuration(self, value):
         self._client_configuration = value
+        if self._api_client:
+            self.api_client
+
+    @property
+    def api_client(self) -> ApiClient:
+        if not self._api_client:
+            self._api_client = self._create_task_client()
+        return self._api_client
+
+    def _create_task_client(self) -> ApiClient:
+        if not self.client_configuration:
+            raise ValueError('No URL to camunda set. Please initialize Library with url or use keyword '
+                             '"Set Camunda URL" first.')
+
+        return ApiClient(self.client_configuration)
+
+
